Reruns inla() for an object of class INLAjoint returned by the joint
function. The rerun starts with posterior values from previous run and can sometimes improve the model fit
(for very complex models or unstable parameter estimates due to low information in the data)
joint.rerun(model, ...)An object of class INLAjoint containing a model fitted with the joint() function.
an object containing a model fitted with the joint() function.
Extra arguments.
joint.