Runs inla() for an object of class INLAjoint returned by the joint
function with argument `run` set to FALSE. The rerun starts with posterior values from
previous run and can sometimes improve the model fit
(for very complex models or unstable parameter estimates due to low information in the data)
joint.run(model, silentMode = FALSE, class = "INLAjoint", ...)An object of class INLAjoint containing a model fitted with the joint() function.
an object containing a model fitted with the joint() function.
boolean to display messages about the fit procedure. Default is FALSE.
defines the class of the object created. Default is "INLAjoint" but can be switched to "inla".
Extra arguments.
joint.